summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/term_enumeration.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/term_enumeration.cpp')
-rw-r--r--src/theory/quantifiers/term_enumeration.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/theory/quantifiers/term_enumeration.cpp b/src/theory/quantifiers/term_enumeration.cpp
index 0b1b1cdae..2945750c1 100644
--- a/src/theory/quantifiers/term_enumeration.cpp
+++ b/src/theory/quantifiers/term_enumeration.cpp
@@ -16,9 +16,9 @@
#include "theory/quantifiers/quant_bound_inference.h"
-using namespace CVC4::kind;
+using namespace CVC5::kind;
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -73,6 +73,6 @@ bool TermEnumeration::getDomain(TypeNode tn, std::vector<Node>& dom)
return true;
}
-} /* CVC4::theory::quantifiers namespace */
-} /* CVC4::theory namespace */
-} /* CVC4 namespace */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback